@@ -4,6 +4,7 @@ from pprint import pprint
 
 import click
 from pymobiledevice3.cli.cli_common import Command, print_json
+from pymobiledevice3.lockdown import LockdownClient
 from pymobiledevice3.services.diagnostics import DiagnosticsService
 
 
@@ -20,26 +21,26 @@ def diagnostics():
 
 
 @diagnostics.command('restart', cls=Command)
-def diagnostics_restart(lockdown):
+def diagnostics_restart(lockdown: LockdownClient):
     """ restart device """
     DiagnosticsService(lockdown=lockdown).restart()
 
 
 @diagnostics.command('shutdown', cls=Command)
-def diagnostics_shutdown(lockdown):
+def diagnostics_shutdown(lockdown: LockdownClient):
     """ shutdown device """
     DiagnosticsService(lockdown=lockdown).shutdown()
 
 
 @diagnostics.command('sleep', cls=Command)
-def diagnostics_sleep(lockdown):
+def diagnostics_sleep(lockdown: LockdownClient):
     """ put device into sleep """
     DiagnosticsService(lockdown=lockdown).sleep()
 
 
 @diagnostics.command('info', cls=Command)
 @click.option('--color/--no-color', default=True)
-def diagnostics_info(lockdown, color):
+def diagnostics_info(lockdown: LockdownClient, color):
     """ get diagnostics info """
     print_json(DiagnosticsService(lockdown=lockdown).info(), colored=color)
 
@@ -48,14 +49,14 @@ def diagnostics_info(lockdown, color):
 @click.option('--plane')
 @click.option('--name')
 @click.option('--ioclass')
-def diagnostics_ioregistry(lockdown, plane, name, ioclass):
+def diagnostics_ioregistry(lockdown: LockdownClient, plane, name, ioclass):
     """ get ioregistry info """
     pprint(DiagnosticsService(lockdown=lockdown).ioregistry(plane=plane, name=name, ioclass=ioclass))
 
 
 @diagnostics.command('mg', cls=Command)
 @click.argument('keys', nargs=-1, default=None)
-def diagnostics_mg(lockdown, keys):
+def diagnostics_mg(lockdown: LockdownClient, keys):
     """ get MobileGestalt key values from given list. If empty, return all known. """
     pprint(DiagnosticsService(lockdown=lockdown).mobilegestalt(keys=keys))
 
@@ -68,14 +69,14 @@ def diagnostics_battery():
 
 @diagnostics_battery.command('single', cls=Command)
 @click.option('--color/--no-color', default=True)
-def diagnostics_battery_single(lockdown, color):
+def diagnostics_battery_single(lockdown: LockdownClient, color):
     """ get single snapshot of battery data """
     raw_info = DiagnosticsService(lockdown=lockdown).get_battery()
     print_json(raw_info, colored=color)
 
 
 @diagnostics_battery.command('monitor', cls=Command)
-def diagnostics_battery_monitor(lockdown):
+def diagnostics_battery_monitor(lockdown: LockdownClient):
     """ monitor battery usage """
     diagnostics = DiagnosticsService(lockdown=lockdown)
     while True:
