@@ -1,9 +1,9 @@
 import tempfile
-from pprint import pprint
 
 import click
-
 from pymobiledevice3.cli.cli_common import Command, print_json
+from pymobiledevice3.lockdown import LockdownClient
+from pymobiledevice3.services.heartbeat import HeartbeatService
 from pymobiledevice3.tcp_forwarder import TcpForwarder
 
 
@@ -23,7 +23,7 @@ def lockdown_group():
 @click.argument('src_port', type=click.IntRange(1, 0xffff))
 @click.argument('dst_port', type=click.IntRange(1, 0xffff))
 @click.option('-d', '--daemonize', is_flag=True)
-def lockdown_forward(lockdown, src_port, dst_port, daemonize):
+def lockdown_forward(lockdown: LockdownClient, src_port, dst_port, daemonize):
     """ forward tcp port """
     forwarder = TcpForwarder(lockdown, src_port, dst_port)
 
@@ -41,26 +41,50 @@ def lockdown_forward(lockdown, src_port, dst_port, daemonize):
 
 
 @lockdown_group.command('recovery', cls=Command)
-def lockdown_recovery(lockdown):
+def lockdown_recovery(lockdown: LockdownClient):
     """ enter recovery """
-    pprint(lockdown.enter_recovery())
+    print_json(lockdown.enter_recovery())
 
 
 @lockdown_group.command('service', cls=Command)
 @click.argument('service_name')
-def lockdown_service(lockdown, service_name):
+def lockdown_service(lockdown: LockdownClient, service_name):
     """ send-receive raw service messages """
     lockdown.start_service(service_name).shell()
 
 
 @lockdown_group.command('info', cls=Command)
 @click.option('--color/--no-color', default=True)
-def lockdown_info(lockdown, color):
+def lockdown_info(lockdown: LockdownClient, color):
     """ query all lockdown values """
     print_json(lockdown.all_values, colored=color)
 
 
 @lockdown_group.command('unpair', cls=Command)
-def lockdown_unpair(lockdown):
+def lockdown_unpair(lockdown: LockdownClient):
     """ unpair from connected device """
     lockdown.unpair()
+
+
+@lockdown_group.command('pair', cls=Command)
+def lockdown_pair(lockdown: LockdownClient):
+    """ pair device """
+    lockdown.pair()
+
+
+@lockdown_group.command('date', cls=Command)
+def lockdown_date(lockdown: LockdownClient):
+    """ get device date """
+    print(lockdown.date)
+
+
+@lockdown_group.command('heartbeat', cls=Command)
+def lockdown_heartbeat(lockdown: LockdownClient):
+    """ start heartbeat service """
+    HeartbeatService(lockdown).start()
+
+
+@lockdown_group.command('language', cls=Command)
+def lockdown_language(lockdown: LockdownClient):
+    """ get current language settings """
+    print(f'{lockdown.language} {lockdown.locale}')
