@@ -1,3 +1,12 @@
+__all__ = [
+    'PyMobileDevice3Exception', 'DeviceVersionNotSupportedError', 'IncorrectModeError', 'DeviceVersionFormatError',
+    'ConnectionFailedError', 'NotTrustedError', 'PairingError', 'NotPairedError', 'CannotStopSessionError',
+    'PasswordRequiredError', 'StartServiceError', 'FatalPairingError', 'NoDeviceConnectedError', 'MuxException',
+    'MuxVersionError', 'ArgumentError', 'AfcException', 'AfcFileNotFoundError', 'DvtException', 'DvtDirListError',
+    'NotMountedError', 'AlreadyMountedError', 'UnsupportedCommandError', 'ExtractingStackshotError'
+]
+
+
 class PyMobileDevice3Exception(Exception):
     pass
 
@@ -50,10 +59,6 @@ class NoDeviceConnectedError(PyMobileDevice3Exception):
     pass
 
 
-class DeviceNonConnectedError(PyMobileDevice3Exception):
-    pass
-
-
 class MuxException(PyMobileDevice3Exception):
     pass
 
@@ -91,6 +96,16 @@ class NotMountedError(PyMobileDevice3Exception):
     pass
 
 
+class AlreadyMountedError(PyMobileDevice3Exception):
+    """ Given image for mount has already been mounted in the first place """
+    pass
+
+
 class UnsupportedCommandError(PyMobileDevice3Exception):
     """ Given command isn't supported for this iOS version """
     pass
+
+
+class ExtractingStackshotError(PyMobileDevice3Exception):
+    """ Raise when stackshot is not received in the core profile session. """
+    pass
