@@ -90,6 +90,14 @@ IRECV_DEVICES = (
                 display_name='iPhone 12 Pro'),
     IRecvDevice(product_type='iPhone13,4', hardware_model='d54pap', board_id=0x08, chip_id=0x8101,
                 display_name='iPhone 12 Pro Max'),
+    IRecvDevice(product_type='iPhone14,2', hardware_model='d63ap', board_id=0x0C, chip_id=0x8110,
+                display_name='iPhone 13 Pro'),
+    IRecvDevice(product_type='iPhone14,3', hardware_model='d64ap', board_id=0x0E, chip_id=0x8110,
+                display_name='iPhone 13 Pro Max'),
+    IRecvDevice(product_type='iPhone14,4', hardware_model='d16ap', board_id=0x08, chip_id=0x8110,
+                display_name='iPhone 13 mini'),
+    IRecvDevice(product_type='iPhone14,5', hardware_model='d17ap', board_id=0x0A, chip_id=0x8110,
+                display_name='iPhone 13'),
     # iPod
     IRecvDevice(product_type='iPod1,1', hardware_model='n45ap', board_id=0x02, chip_id=0x8900,
                 display_name='iPod Touch (1st gen)'),
@@ -226,7 +234,11 @@ IRECV_DEVICES = (
     IRecvDevice(product_type='iPad11,6', hardware_model='j171aap', board_id=0x24, chip_id=0x8020,
                 display_name='iPad (8th gen, WiFi)'),
     IRecvDevice(product_type='iPad11,7', hardware_model='j172aap', board_id=0x26, chip_id=0x8020,
-                display_name='iPad (8th gen, Celluar)'),
+                display_name='iPad (8th gen, Cellular)'),
+    IRecvDevice(product_type='iPad12,1', hardware_model='j181ap', board_id=0x18, chip_id=0x8030,
+                display_name='iPad (9th gen, WiFi)'),
+    IRecvDevice(product_type='iPad12,2', hardware_model='j182ap', board_id=0x1A, chip_id=0x8030,
+                display_name='iPad (9th gen, Cellular)'),
     IRecvDevice(product_type='iPad13,1', hardware_model='j307ap', board_id=0x04, chip_id=0x8101,
                 display_name='iPad Air (4th gen, WiFi)'),
     IRecvDevice(product_type='iPad13,2', hardware_model='j308ap', board_id=0x06, chip_id=0x8101,
@@ -238,15 +250,19 @@ IRECV_DEVICES = (
     IRecvDevice(product_type='iPad13,6', hardware_model='j518ap', board_id=0x0C, chip_id=0x8103,
                 display_name='iPad Pro 11-inch (3rd gen, Cellular)'),
     IRecvDevice(product_type='iPad13,7', hardware_model='j518xap', board_id=0x0E, chip_id=0x8103,
-                display_name='iPad Pro 11-inch (3rd gen, Celluar, 2TB)'),
+                display_name='iPad Pro 11-inch (3rd gen, Cellular, 2TB)'),
     IRecvDevice(product_type='iPad13,8', hardware_model='j522ap', board_id=0x18, chip_id=0x8103,
                 display_name='iPad Pro 12.9-inch (5th gen, WiFi)'),
     IRecvDevice(product_type='iPad13,9', hardware_model='j522xap', board_id=0x1A, chip_id=0x8103,
                 display_name='iPad Pro 12.9-inch (5th gen, WiFi, 2TB)'),
     IRecvDevice(product_type='iPad13,10', hardware_model='j523ap', board_id=0x1C, chip_id=0x8103,
-                display_name='iPad Pro 12.9-inch (5th gen, Celluar)'),
+                display_name='iPad Pro 12.9-inch (5th gen, Cellular)'),
     IRecvDevice(product_type='iPad13,11', hardware_model='j523xap', board_id=0x1E, chip_id=0x8103,
-                display_name='iPad Pro 12.9-inch (5th gen, Celluar, 2TB)'),
+                display_name='iPad Pro 12.9-inch (5th gen, Cellular, 2TB)'),
+    IRecvDevice(product_type='iPad14,1', hardware_model='j310ap', board_id=0x04, chip_id=0x8110,
+                display_name='iPad mini (6th gen, WiFi)'),
+    IRecvDevice(product_type='iPad14,2', hardware_model='j311ap', board_id=0x06, chip_id=0x8110,
+                display_name='iPad mini (6th gen, Cellular)'),
     # Apple TV
     IRecvDevice(product_type='AppleTV2,1', hardware_model='k66ap', board_id=0x10, chip_id=0x8930,
                 display_name='Apple TV 2'),
@@ -320,6 +336,14 @@ IRECV_DEVICES = (
                 display_name='Apple Watch Series 6 (40mm Cellular)'),
     IRecvDevice(product_type='Watch6,4', hardware_model='n158bap', board_id=0x0E, chip_id=0x8301,
                 display_name='Apple Watch Series 6 (44mm Cellular)'),
+    IRecvDevice(product_type='Watch6,6', hardware_model='n187sap', board_id=0x10, chip_id=0x8301,
+                display_name='Apple Watch Series 7 (41mm)'),
+    IRecvDevice(product_type='Watch6,7', hardware_model='n187bap', board_id=0x12, chip_id=0x8301,
+                display_name='Apple Watch Series 7 (45mm)'),
+    IRecvDevice(product_type='Watch6,8', hardware_model='n188sap', board_id=0x14, chip_id=0x8301,
+                display_name='Apple Watch Series 7 (41mm Cellular)'),
+    IRecvDevice(product_type='Watch6,9', hardware_model='n188bap', board_id=0x16, chip_id=0x8301,
+                display_name='Apple Watch Series 7 (45mm Cellular)'),
     # Apple Silicon Macs
     IRecvDevice(product_type='ADP3,2', hardware_model='j273aap', board_id=0x42, chip_id=0x8027,
                 display_name='Developer Transition Kit'),
