@@ -5,7 +5,7 @@ import struct
 import threading
 from enum import Enum
 
-from pymobiledevice3.exceptions import NoDeviceConnectedError, DeviceNonConnectedError, PyMobileDevice3Exception
+from pymobiledevice3.exceptions import NoDeviceConnectedError, ConnectionFailedError, PyMobileDevice3Exception
 from pymobiledevice3.lockdown import list_devices
 from pymobiledevice3.service_connection import ServiceConnection
 
@@ -41,7 +41,7 @@ class FDRClient:
             udid = available_udids[0]
         else:
             if udid not in available_udids:
-                raise DeviceNonConnectedError()
+                raise ConnectionFailedError()
 
         logging.debug('connecting to FDR')
 
@@ -126,7 +126,9 @@ class FDRClient:
         # Connect: 0 3 hostlen <host> <port>
         if buf[0] == 0 and buf[1] == 3:
             port = struct.unpack('>H', buf[-2:])[0]
-            host = buf[3:].split(b'\x00', 1)[0]
+            hostlen = buf[2]
+            host = buf[3:3 + hostlen]
+
             logging.debug(f'FDR {self} Proxy connect request to {host}:{port}')
 
         if host is None:
@@ -136,13 +138,27 @@ class FDRClient:
         sockfd = socket.socket()
         sockfd.connect((host, port))
 
+        sockfd.settimeout(.1)
+        self.service.socket.settimeout(.1)
+
         while True:
-            buf = self.service.recv(1048576)
-            logging.debug(f'FDR {self} got payload of {len(buf)} bytes, now try to proxy it')
-            logging.debug(f'Sending {len(buf)} bytes of data')
-            sockfd.sendall(buf)
+            buf = b''
+            try:
+                buf = self.service.recv(1048576)
+            except socket.timeout:
+                pass
+
+            if buf:
+                logging.debug(f'FDR {self} got payload of {len(buf)} bytes, now try to proxy it')
+                logging.debug(f'Sending {len(buf)} bytes of data')
+                sockfd.sendall(buf)
+
+            buf = b''
+            try:
+                buf = sockfd.recv(1048576)
+            except socket.timeout:
+                pass
 
-            buf = sockfd.recv(1048576)
             self.service.sendall(buf)
 
     def handle_plist_cmd(self):
